<?php
require_once '../Logic/config.php';
require_once '../Logic/session_start.php';

function updateUserInformation($userId, $name, $email, $major, $year)
{
    $sql = "UPDATE user SET user_Name = ?, email = ?, user_Major = ?, enrollment_Year = ? WHERE id = ?";
    $stmt = DB->prepare($sql);
    return $stmt->execute([$name, $email, $major, $year, $userId]);
}

function updateAccountInfo($account, $password, $userId)
{
    $sql = "UPDATE user SET account = ?, password = ? WHERE id = ?";
    $stmt = DB->prepare($sql);
    return $stmt->execute([$account, $password, $userId]);
}

// 检查是否有POST请求提交表单
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 检查是否存在userId参数
    $userID = isset($_POST['userId']) ? $_POST['userId'] : null;

    // 处理表单提交的数据
    if ($_POST["formType"] == "UserForm") {
        // 获取表单数据
        $name = $_POST['name'];
        $email = $_POST['email'];
        $major = $_POST['major'];
        $year = $_POST['year'];
        // 调用函数更新用户信息
        updateUserInformation($userID, $name, $email, $major, $year);
    } elseif ($_POST["formType"] == "ModalForm") {
        $account = $_POST['account'];
        $password = $_POST['password'];
        updateAccountInfo($account, $password, $userID);
    } elseif ($_POST["formType"] == "AvatarForm") {
        // 读取文件内容
        $avatar_name = $_FILES["avatar"]["name"];
        $avatar_size = $_FILES['avatar']['size'];
        $avatar_type = $_FILES['avatar']['type'];
        $avatar = $_FILES['avatar']['tmp_name'];

        $data = addslashes(fread(fopen($avatar, "r"), filesize($avatar)));

        $dsn = 'mysql:dbname=zhushou;host=localhost';
        $pdo = new PDO($dsn, 'root', 'czx2002819');
        $data = addslashes(fread(fopen($avatar, "r"), filesize($avatar)));

        $result = $pdo->query("UPDATE avatar SET user_Avatar = '$data', filename = '$avatar_name', filesize = '$avatar_size', filetype = '$avatar_type' WHERE id = '$userID'");
    }

}

// 准备SQL查询
$stmt = DB->prepare("SELECT * FROM user WHERE id = ?");
$stmt->execute([$userID]);
$user = $stmt->fetch(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User Information Management</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css">
    <link rel="stylesheet" href="../css/settings.css">
</head>
<body>
<?php include '../Logic/translate.php'; ?>

<div class="container">

    <div id="topbar">
        <div id="logo">UWE Student Assistant</div>
    </div>

    <div class="card">
        <div class="avatar">
            <img src="../Logic/getimage.php?userId=<?php echo htmlspecialchars($userID); ?>" alt="User Avatar">
        </div>
        <div class="input-group">
            <label for="name">Name:</label>
            <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($user['user_Name']); ?>"
                   disabled>
        </div>
        <div class="input-group">
            <label for="email">Email:</label>
            <input type="text" id="email" name="email" value="<?php echo htmlspecialchars($user['email']); ?>" disabled>
        </div>
        <div class="input-group">
            <label for="major">Major:</label>
            <input type="text" id="major" name="major" value="<?php echo htmlspecialchars($user['user_Major']); ?>"
                   disabled>
        </div>
        <div class="input-group">
            <label for="year">Enrollment Year:</label>
            <input type="text" id="year" name="year"
                   value="<?php echo htmlspecialchars($user['enrollment_Year']); ?>" disabled>
        </div>
        <button class="button" onclick="openAvaModal(event)">Change Avatar</button>
    </div>

    <!-- 模态框 -->
    <form action="settings.php" method="post" enctype="multipart/form-data">
        <div id="avatarModal" class="modal">
            <div class="modal-content">
                <span class="close" onclick="closeAvaModal()">&times;</span>
                <h2>Edit Avatar</h2>
                <div class="input-group">
                    <label for="newUsername">Upload Avatar:</label>
                    <input type="file" name="avatar" id="avatar">
                </div>
                <input type="hidden" name="formType" value="AvatarForm">
                <!--      隐藏字段用于在提交表单时传递userid-->
                <input type="hidden" name="userId" value="<?php echo htmlspecialchars($userID); ?>">
                <button class="modern-button" type="submit">Save Changes</button>
            </div>
        </div>
    </form>

    <div class="card">
        <h2>Account Information</h2>
        <div class="input-group">
            <label for="username">User Account:</label>
            <input type="text" id="username" name="account" value="<?php echo htmlspecialchars($user['account']); ?>"
                   disabled>
        </div>
        <div class="input-group">
            <label for="password">Password:</label>
            <input type="password" id="password" name="password"
                   value="<?php echo htmlspecialchars($user['password']); ?>" disabled>
            <button class="toggle-btn" onclick="togglePasswordVisibility()">👁</button>
        </div>
        <button class="modern-button" onclick="openModal()">Edit Your Info</button>
    </div>

    <!-- 模态框 -->
    <form action="settings.php" method="post">
        <div id="myModal" class="modal">
            <div class="modal-content">
                <span class="close" onclick="closeModal()">&times;</span>
                <h2>Edit Credentials</h2>
                <div class="input-group">
                    <label for="newUsername">New account:</label>
                    <input id="newUsername" name="account">
                </div>
                <div class="input-group">
                    <label for="newPassword">New Password:</label>
                    <input id="newPassword" name="password" pattern="(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*\W).{8,}"
                           required
                           title="Password must be at least 8 characters long, including 1 uppercase letter, 1 special character, and 1 number.">
                </div>
                <input type="hidden" name="formType" value="ModalForm">
                <!--      隐藏字段用于在提交表单时传递userid-->
                <input type="hidden" name="userId" value="<?php echo htmlspecialchars($userID); ?>">
                <button class="modern-button" type="submit">Save Changes</button>
            </div>
        </div>
    </form>

    <div class="card">
        <h2>More information</h2>
        <p>if you wanna get your marks, documents or know your tution fee, pls go this link👇</p>
        <button onclick="window.location.href='https://my.uwe.ac.uk/uPortal/f/u28l1s4100/normal/render.uP';"
                class="modern-button">Go to myuwe
        </button>
    </div>

    <form action="../Logic/logout.php" method="post">
        <div class="card">
            <h2>Log Out</h2>
            <p>Click the button below to log out of your account.</p>
            <button class="modern-button" type="submit">Log Out</button>
        </div>
        <!--    </form>再加一个模态框来确定用户是否退出账号-->
</div>


<a href="interface.php" id="return-home-btn"><i class="fas fa-arrow-left"></i></a>

<!--src="js/settings.js"-->
<script src="../Logic/settings.js"></script>
</body>
</html>
